package game

import (
	"net/url"
	"support-game/controllers"
	"support-game/service/game"
	"support-game/utils"
)

// SupportController 活动
type SupportController struct {
	serv *game.SupportServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *SupportController) Constructor() {
	c.serv = game.NewSupportServ(c.Context)
}

// GetCustomer 获取用户信息
func (c *SupportController) GetCustomer() {
	code := c.GetString(":code")
	customer, err := c.serv.GetCustomerByCode(code)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(customer)
}

// SignUp 注册
func (c *SupportController) SignUp() {
	customerid := c.GetString(":customerid")
	name := c.GetString("name")
	phone := c.GetString("phone")
	address := c.GetString("address")
	customer, err := c.serv.SignUp(customerid, name, phone, address)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(customer)
}

// GetGame 获取主信息
func (c *SupportController) GetGame() {
	gameid := c.GetString(":gameid")
	customerid := c.GetString(":customerid")
	info, err := c.serv.GetGameInfo(gameid, customerid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(info)
}

// GetRecord 获取报名信息
func (c *SupportController) GetRecord() {
	recordid := c.GetString(":recordid")
	info, err := c.serv.GetRecordInfo(recordid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(info)
}

// AddRecord 参加活动
func (c *SupportController) AddRecord() {
	customerid := c.GetString(":customerid")
	gameid := c.GetString(":gameid")
	record, err := c.serv.AddRecord(customerid, gameid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(record)
}

// AddSupport 助力
func (c *SupportController) AddSupport() {
	customerid := c.GetString(":customerid")
	recordid := c.GetString(":recordid")
	info, err := c.serv.AddSupport(recordid, customerid)
	if err != nil {
		c.ResponseError(err)
	}
	c.ResponseJSON(info)
}

// WechatInfo 微信接入
func (c *SupportController) WechatInfo() {
	echostr := c.GetString("echostr")
	c.ResponseRaw([]byte(echostr))
}

// GetWxJsSDKSignature 获取 微信 jssdk 签名
func (c *SupportController) GetWxJsSDKSignature() {
	url, _ := url.QueryUnescape(c.GetString("url"))

	res := utils.WxClient().GetJsTicketSignature(url)
	c.ResponseJSON(res)
}
