package game

import (
	"errors"
	"support-game/controllers"
	gamemodel "support-game/models/game"
	"support-game/models/model"
	"support-game/service/game"
)

// VotingController 活动
type VotingController struct {
	serv *game.VotingServ
	controllers.BaseController
}

// Constructor 初始化 Controller
// @Title Constructor
// @Description 初始化 Controller, 系统自动调用
func (c *VotingController) Constructor() {
	c.serv = game.NewVotingServ(c.Context)
}

// List 获取列表
func (c *VotingController) List() {
	// 活动
	actID, _ := c.GetInt("actid")

	// 分页
	page, _ := c.GetInt("page")
	if page < 1 {
		page = 1
	}
	page -= 1

	// tab 类型
	tab, _ := c.GetInt("tab")

	// 搜索条件
	search := c.GetString("q")
	list, err := c.serv.GetList(actID, search, tab, page)
	if err != nil {
		c.ResponseError(errors.New("查询列表失败, 请重试"))
	}

	c.ResponseJSON(list)
}

// Activities 活动详情
func (c *VotingController) Activities() {
	// 活动
	actID, _ := c.GetInt(":actid")
	activitie, err := c.serv.GetActivitiesInfo(actID)
	if err != nil {
		c.ResponseError(errors.New("查询活动失败，请重试"))
	}

	c.ResponseJSON(activitie)
}

// Detail 报名详情
func (c *VotingController) Detail() {
	// 活动
	actID, _ := c.GetInt(":actid")
	memberid, _ := c.GetInt(":memberid")
	activitie, err := c.serv.GetMemberInfo(actID, memberid)
	if err != nil {
		c.ResponseError(errors.New("查询活动详情失败，请重试"))
	}

	c.ResponseJSON(activitie)
}

// Registe 报名
func (c *VotingController) Registe() {
	// 活动
	actID, _ := c.GetInt(":actid")
	member := gamemodel.MemInfo{}
	if err := c.ParseForm(&member); err != nil {
		c.ResponseError(errors.New("参数错误！"))
	}
	member.ActivityId = actID
	err := c.serv.Registe(&member)
	if err != nil {
		c.ResponseError(errors.New("查询活动详情失败，请重试"))
	}
	c.ResponseJSON(member)
}

// Vote 投票
func (c *VotingController) Vote() {
	actID, _ := c.GetInt(":actid")
	memberid, _ := c.GetInt(":memberid")
	openid := c.GetString("openid")
	record := model.TaVotingRecords{
		ActivityId: actID,
		MemberId:   memberid,
		Openid:     openid,
	}

	err := c.serv.Vote(&record)
	if err != nil {
		c.ResponseError(errors.New("投票失败，请重试"))
	}
	c.ResponseJSON(record)
}
