package game

import (
	"errors"
	"support-game/models/game"
	"support-game/models/model"
	"support-game/utils"
)

// VotingServ 活动serv
type VotingServ struct {
	ctx *utils.Context
	dao *game.VotingModel
}

// NewVotingServ 初始化
func NewVotingServ(ctx *utils.Context) *VotingServ {
	return &VotingServ{
		ctx: ctx,
		dao: game.NewVotingModel(ctx),
	}
}

// GetList 投票列表信息
func (s *VotingServ) GetList(actID int, search string, orderby, page int) ([]game.MemInfo, error) {
	list, err := s.dao.List(actID, search, orderby, page)
	if err != nil {
		utils.LogError("获取投票列表失败：", err)
		return nil, errors.New("获取投票列表失败，请重试")
	}
	return list, nil
}

// GetActivitiesInfo 获取活动详情
func (s *VotingServ) GetActivitiesInfo(actid int) (*model.TaVotingActivities, error) {
	info, err := s.dao.GetActivityInfo(actid)
	if err != nil {
		utils.LogError("获取投票详情失败：", err)
		return nil, errors.New("获取投票详情失败，请重试")
	}
	return info, nil
}

// GetMemberIndo 获取报名详情
func (s *VotingServ) GetMemberInfo(actid, memberid int) (*game.MemInfo, error) {
	info, err := s.dao.GetMemInfo(actid, memberid)
	if err != nil {
		utils.LogError("获取报名详情失败：", err)
		return nil, errors.New("获取报名详情失败，请重试")
	}
	return info, nil
}

// Registe 报名
func (s *VotingServ) Registe(memInfo *game.MemInfo) error {
	err := s.dao.Registe(memInfo)
	if err != nil {
		utils.LogError("报名失败：", err)
		return errors.New("操作失败，请重试")
	}
	return nil
}

// Vote 投票
func (s *VotingServ) Vote(rec *model.TaVotingRecords) error {
	err := s.dao.Vote(rec)
	if err != nil {
		utils.LogError("投票失败：", err)
		return errors.New("操作失败，请重试")
	}
	return nil
}
